OpenAIFineTuneEventStreamModel class final

Creates a new instance of OpenAIFineTuneEventStreamModel.

Annotations

Constructors

OpenAIFineTuneEventStreamModel({required String level, required String message, required DateTime createdAt})
Creates a new instance of OpenAIFineTuneEventStreamModel.
const
OpenAIFineTuneEventStreamModel.fromMap(Map<String, dynamic> json)
Creates a new instance of OpenAIFineTuneEventStreamModel. Creates a new instance of OpenAIFineTuneEventStreamModel from a Map.
factory

Properties

createdAt → DateTime
The time the event was created.
final
hashCode → int
The hash code for this object.
no setteroverride
level → String
The level of the event.
final
message → String
The message of the event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant OpenAIFineTuneEventStreamModel other) → bool
The equality operator.
override