OpenAIModerationModel class final

This class is used to represent an OpenAI moderation job.

Annotations

Constructors

OpenAIModerationModel({required String id, required String model, required List<OpenAIModerationResultModel> results})
This class is used to represent an OpenAI moderation job.
const
OpenAIModerationModel.fromMap(Map<String, dynamic> json)
This method is used to convert a Map<String, dynamic> object to a OpenAIModerationModel object.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
haveResults → bool
Weither the moderation job have at least one result in results.
no setter
id → String
The identifier of the moderation job.
final
model → String
The model used for moderation.
final
results → List<OpenAIModerationResultModel>
The results of the moderation job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant OpenAIModerationModel other) → bool
The equality operator.
override