OpenAIModerationResultModel class final

This class is used to represent an OpenAI moderation job result.

Annotations

Constructors

OpenAIModerationResultModel({required OpenAIModerationResultCategoriesModel categories, required OpenAIModerationResultScoresModel categoryScores, required bool flagged})
This class is used to represent an OpenAI moderation job result.
const
OpenAIModerationResultModel.fromMap(Map<String, dynamic> json)
This method is used to convert a Map<String, dynamic> object to a OpenAIModerationResultModel object.
factory

Properties

categories → OpenAIModerationResultCategoriesModel
The categories of the moderation job.
final
categoryScores → OpenAIModerationResultScoresModel
The category scores of the moderation job.
final
flagged → bool
The flagged status of the moderation job.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant OpenAIModerationResultModel other) → bool
The equality operator.
override