Segment class final

Constructors

Segment({required int id, required int seek, required double start, required double end, required String text, required List<int> tokens, required double temperature, required double avg_logprob, required double compression_ratio, required double no_speech_prob})
const
Segment.fromMap(Map<String, dynamic> json)
factory

Properties

avg_logprob → double
final
compression_ratio → double
final
end → double
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
no_speech_prob → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seek → int
final
start → double
final
temperature → double
final
text → String
final
tokens → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override